#include "DeerStudio/EditorEngine/ServiceScript/ServiceScriptObject.h"
#include "DeerStudio/EditorEngine/ErrorHandle.h"
#include "DeerStudio/EditorEngine.h"
#include "angelscript.h"

#include <string>

namespace Deer {
    namespace EditorEngine {
        ServiceScriptObject::ServiceScriptObject(asITypeInfo* _type, asIScriptContext* _scriptContext)
            : type(_type), scriptContext(_scriptContext) {
            // Constructor
            // "type@ type()" 
            std::string callString;
            const std::string ns(type->GetNamespace());
            if (ns != "") {
                callString += ns;
                callString += "::";
            }
            callString += type->GetName();
            callString += "@ ";
            if (ns != "") {
                callString += ns;
                callString += "::";
            }
            callString += type->GetName();
            callString += "()";

            asIScriptFunction* factory = type->GetFactoryByDecl(callString.c_str());

            AS_CHECK(scriptContext->Prepare(factory));
            AS_CHECK(scriptContext->Execute());

            // Return value contains the ref to a asIScriptObject in the location provided
            object = *(asIScriptObject**)scriptContext->GetAddressOfReturnValue();
            if (!object){
                DEER_EDITOR_ENGINE_ERROR("Could not create object", type->GetName());
                return;
            }
            object->AddRef();

            updateFunction = type->GetMethodByDecl("void onUpdate()");
            initFunction = type->GetMethodByDecl("void onInit()");

            scriptContext->Unprepare();
        }

        ServiceScriptObject::~ServiceScriptObject() {
            if (object)
                object->Release();
        }

        void ServiceScriptObject::init() {
            if (!initFunction)
                return;

            AS_CHECK(scriptContext->Prepare(initFunction));
            AS_CHECK(scriptContext->SetObject(object));
            AS_CHECK(scriptContext->Execute());
            AS_CHECK(scriptContext->Unprepare());
        }

        void ServiceScriptObject::update() {
            if (!updateFunction)
                return;

            AS_CHECK(scriptContext->Prepare(updateFunction));
            AS_CHECK(scriptContext->SetObject(object));
            AS_CHECK(scriptContext->Execute());
            AS_CHECK(scriptContext->Unprepare());
        }

        const char* ServiceScriptObject::getName() {
            return type->GetName();
        }

        ServiceScriptObject::ServiceScriptObject(ServiceScriptObject&& other) noexcept {
            type = other.type;
            object = other.object;
            updateFunction = other.updateFunction;
            initFunction = other.initFunction;
            scriptContext = other.scriptContext;

            other.type = nullptr;
            other.object = nullptr;
            other.updateFunction = nullptr;
            other.initFunction = nullptr;
            other.scriptContext = nullptr;
        }

        ServiceScriptObject& ServiceScriptObject::operator=(ServiceScriptObject&& other) noexcept {
            if (&other != this) {
                type = other.type;
                object = other.object;
                updateFunction = other.updateFunction;
                initFunction = other.initFunction;
                scriptContext = other.scriptContext;
                
                other.type = nullptr;
                other.object = nullptr;
                other.updateFunction = nullptr;
                other.initFunction = nullptr;
                other.scriptContext = nullptr;
            }
            return *this;
        }
    }
}